@@ -16,10 +16,12 @@ from django.utils.translation import ugettext_lazy as _  # noqa
 
 import horizon
 
+from tuskar_ui.infrastructure import dashboard
+
 
 class Overview(horizon.Panel):
     name = _("Overview")
     slug = "overview"
 
 
-#dashboard.Infrastructure.register(Overview)
+dashboard.Infrastructure.register(Overview)
